@@ -72,24 +72,23 @@ def transform_anchor(ax, ay, w, h, angle):
 
 class Actor:
     EXPECTED_INIT_KWARGS = SYMBOLIC_POSITIONS
-    DELEGATED_ATTRIBUTES = [a for a in dir(rect.ZRect) if not a.startswith("_")] + ["collide_mask"]
+    DELEGATED_ATTRIBUTES = [a for a in dir(rect.ZRect) if not a.startswith("_")]
 
     _anchor = _anchor_value = (0, 0)
-    _angle = 0.0
 
-    def __init__(self, image, pos=POS_TOPLEFT, _size = 100,anchor=ANCHOR_CENTER, **kwargs):
+    def __init__(self, image, pos=POS_TOPLEFT,_angle = 0,Size = 100,anchor=ANCHOR_CENTER, **kwargs):
         self._handle_unexpected_kwargs(kwargs)
-
+        self._angle = _angle
         self.__dict__["_rect"] = rect.ZRect((0, 0), (0, 0))
         # Initialise it at (0, 0) for size (0, 0).
         # We'll move it to the right place and resize it later
-        self._size = _size
+        self._size = Size
         self.image = image
         self._init_position(pos, anchor, **kwargs)
 
     def __getattr__(self, attr):
         # print(attr)
-        if attr in self.__class__.DELEGATED_ATTRIBUTES or attr == 'collide_mask':
+        if attr in self.__class__.DELEGATED_ATTRIBUTES :
             return getattr(self._rect, attr)
         else:
             return object.__getattribute__(self, attr)
@@ -154,7 +153,7 @@ class Actor:
 
     def _calc_anchor(self):
         ax, ay = self._anchor_value
-        print(f"ax:{ax},ay:{ay}")
+        # print(f"ax:{ax},ay:{ay}")
         ow, oh = self._orig_surf.get_size()
         ax = calculate_anchor(ax, 'x', ow)
         ay = calculate_anchor(ay, 'y', oh)
@@ -178,15 +177,7 @@ class Actor:
         ax, ay = self._untransformed_anchor
         self._anchor = transform_anchor(ax, ay, w, h, angle)
         self.pos = p
-    @property
-    def Size(self):
-        return self._size
-    @Size.setter
-    def Size(self,new_size):
-        self._w,self._h = self._surf.get_size()
-        self._orig_surf = self._surf = pygame.transform.scale(self._surf,(int(self._w*new_size/100),int(self._h*new_size/100)))
-        self._update_pos()
-        self._size = new_size
+
     @property
     def pos(self):
         px, py = self.topleft
@@ -228,6 +219,7 @@ class Actor:
         self._w, self._h = self._surf.get_size()
         self._orig_surf = self._surf = pygame.transform.scale(self._surf, (
         int(self._w * self._size / 100), int(self._h * self._size / 100)))
+        self._w, self._h = self._surf.get_size()
         self._update_pos()
 
     def _update_pos(self):
@@ -260,6 +252,7 @@ class Actor:
         dx = tx - myx
         dy = ty - myy
         return sqrt(dx * dx + dy * dy)
+    # yt_zxx升级
     def collide_mask(self,others):
         # print(self._rect)
         xoffset = others._rect[0] - self._rect[0]
@@ -278,3 +271,29 @@ class Actor:
         # print(-radians(self.angle))
         self.x -= steps*sin(radians(self.angle))
         self.y -= steps*cos(radians(self.angle))
+    def face_to(self,target):
+        self.angle = self.angle_to(target) - 90
+    def in_the_edge(self):
+        self._bounds = game.screen.bounds()
+        if self.x > self._bounds[2]:
+            self.x = self._bounds[2]
+        if self.x < 0:
+            self.x = 0
+        if self.y > self._bounds[3]:
+            self.y = self._bounds[3]
+        if self.y < 0:
+            self.y = 0
+    def out_of_edge(self):
+        self._bounds = game.screen.bounds()
+        return not(0-self._w < self.x < self._bounds[2]+self._w and 0-self._h < self.y < self._bounds[3]+self._h)
+    @property
+    def Size(self):
+        return self._size
+    @Size.setter
+    def Size(self,new_size):
+        self._w,self._h = self._surf.get_size()
+        self._orig_surf = self._surf = pygame.transform.scale(self._surf,(int(self._w*new_size/100),int(self._h*new_size/100)))
+        self._update_pos()
+        self._size = new_size
+    def yt(self):
+        print("没想到吧!,我就是升级那个曾老师")
\ No newline at end of file
